#!/bin/bash

if [ "$IMAGE_TAG" == "" ]; then
  echo "Make sure IMAGE_TAG is set"
  exit 1
fi


IMAGE_NAME=gitea.hottis.de/wn/jupyter-scipy-database-extension
NAMESPACE=jupyter
DEPLOYMENT_DIR=$PWD/deployment

pushd $DEPLOYMENT_DIR > /dev/null
./decrypt-secrets.sh || exit 1 
. /tmp/secrets
rm /tmp/secrets

kubectl create namespace $NAMESPACE \
  --dry-run=client \
  -o yaml | \
  kubectl -f - apply

kubectl create secret generic traefik-forward-auth \
  --dry-run=client \
  -o yaml \
  --save-config \
  --from-literal=PROVIDERS_OIDC_CLIENT_SECRET="$PROVIDERS_OIDC_CLIENT_SECRET" \
  --from-literal=SECRET="$SECRET" | \
  kubectl apply -f - -n $NAMESPACE


cat $DEPLOYMENT_DIR/deploy-yml.tmpl | \
  sed -e 's,%IMAGE%,'$IMAGE_NAME':'$IMAGE_TAG','g | \
  kubectl apply -f - -n $NAMESPACE

popd > /dev/null


